@@ -19,7 +19,7 @@
 
 #include "tkm_id_manager.h"
 
-static const tkm_limits_t limits = {125, 100, 55, 30, 200, 42};
+static const tkm_limits_t limits = {125, 100, 55, 30, 200, 42, 21};
 
 START_TEST(test_id_mgr_creation)
 {
