@@ -1,9 +1,9 @@
 /*
- * Copyright (C) 2011-2014 Tobias Brunner
+ * Copyright (C) 2011-2018 Tobias Brunner
  * Copyright (C) 2005-2010 Martin Willi
- * Copyright (C) 2010 revosec AG
  * Copyright (C) 2005 Jan Hutter
- * HSR Hochschule fuer Technik Rapperswil
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -326,6 +326,21 @@ METHOD2(payload_t, encrypted_payload_t, get_length, size_t,
 	return this->payload_length;
 }
 
+METHOD2(payload_t, encrypted_payload_t, get_length_plain, size_t,
+	private_encrypted_payload_t *this)
+{
+	/* contains only the decrypted payload data, no IV, padding or ICV */
+	this->payload_length = this->encrypted.len;
+
+	if (this->aead)
+	{
+		this->payload_length += compute_overhead(this->aead,
+												 this->payload_length);
+	}
+	this->payload_length += get_header_length(this);
+	return this->payload_length;
+}
+
 METHOD(encrypted_payload_t, add_payload, void,
 	private_encrypted_payload_t *this, payload_t *payload)
 {
@@ -727,6 +742,12 @@ METHOD(encrypted_payload_t, set_transform, void,
 	this->aead = aead;
 }
 
+METHOD(encrypted_payload_t, get_transform, aead_t*,
+	private_encrypted_payload_t *this)
+{
+	return this->aead;
+}
+
 METHOD2(payload_t, encrypted_payload_t, destroy, void,
 	private_encrypted_payload_t *this)
 {
@@ -759,6 +780,7 @@ encrypted_payload_t *encrypted_payload_create(payload_type_t type)
 			.remove_payload = _remove_payload,
 			.generate_payloads = _generate_payloads,
 			.set_transform = _set_transform,
+			.get_transform = _get_transform,
 			.encrypt = _encrypt,
 			.decrypt = _decrypt,
 			.destroy = _destroy,
@@ -787,10 +809,11 @@ encrypted_payload_t *encrypted_payload_create_from_plain(payload_type_t next,
 	private_encrypted_payload_t *this;
 
 	this = (private_encrypted_payload_t*)encrypted_payload_create(PLV2_ENCRYPTED);
+	this->public.payload_interface.get_length = _get_length_plain;
+	this->public.get_length = _get_length_plain;
 	this->public.decrypt = _decrypt_plain;
 	this->next_payload = next;
 	this->encrypted = plain;
-	compute_length(this);
 
 	return &this->public;
 }
@@ -899,6 +922,12 @@ METHOD(encrypted_payload_t, frag_set_transform, void,
 	this->aead = aead;
 }
 
+METHOD(encrypted_payload_t, frag_get_transform, aead_t*,
+	private_encrypted_fragment_payload_t *this)
+{
+	return this->aead;
+}
+
 /**
  * Append the encrypted fragment payload header to the associated data
  */
@@ -996,6 +1025,7 @@ encrypted_fragment_payload_t *encrypted_fragment_payload_create()
 				.remove_payload = (void*)return_null,
 				.generate_payloads = nop,
 				.set_transform = _frag_set_transform,
+				.get_transform = _frag_get_transform,
 				.encrypt = _frag_encrypt,
 				.decrypt = _frag_decrypt,
 				.destroy = _frag_destroy,
