@@ -186,7 +186,7 @@ METHOD(eap_method_t, process_server, status_t,
 }
 
 METHOD(eap_method_t, get_type, eap_type_t,
-	private_eap_gtc_t *this, uint32_t *vendor)
+	private_eap_gtc_t *this, pen_t *vendor)
 {
 	*vendor = 0;
 	return EAP_GTC;
