@@ -340,7 +340,7 @@ METHOD(backend_t, create_peer_cfg_enumerator, enumerator_t*,
 static job_requeue_t initiate_config(peer_cfg_t *peer_cfg)
 {
 	enumerator_t *enumerator;
-	child_cfg_t *child_cfg = NULL;;
+	child_cfg_t *child_cfg = NULL;
 
 	enumerator = peer_cfg->create_child_cfg_enumerator(peer_cfg);
 	enumerator->enumerate(enumerator, &child_cfg);
