@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2011 Andreas Steffen
- * HSR Hochschule fuer Technik Rapperswil
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -38,9 +39,7 @@ struct tnc_pdp_t {
 
 /**
  * Create a TNC PDP instance
- *
- * @param port		RADIUS port of TNC PDP
  */
-tnc_pdp_t* tnc_pdp_create(u_int16_t port);
+tnc_pdp_t* tnc_pdp_create(void);
 
 #endif /** TNC_PDP_PLUGIN_H_ @}*/
