@@ -53,7 +53,7 @@ Vici::Transport - Perl extension for communicating via a strongSwan VICI socket
 
 =head1 SYNOPSIS
 
-  use Vici::Transport;
+use Vici::Transport;
 
 =head1 DESCRIPTION
 
@@ -69,9 +69,7 @@ None by default.
 
 =head1 SEE ALSO
 
-strongSwan Wiki:  https://wiki.strongswan.org/projects/strongswan/wiki/Vici
-
-strongSwan Mailing list:  users@lists.strongswan.org
+strongSwan Documentation:  https://docs.strongswan.org/docs/5.9/plugins/vici.html
 
 =head1 AUTHOR
 
