@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2011 Tobias Brunner
- * HSR Hochschule fuer Technik Rapperswil
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -43,7 +44,7 @@ struct keymat_v1_t {
 	 * crypters and authentication functions.
 	 *
 	 * @param proposal		selected algorithms
-	 * @param dh			diffie hellman key allocated by create_dh()
+	 * @param dh			diffie hellman key allocated by create_ke()
 	 * @param dh_other		public DH value from other peer
 	 * @param nonce_i		initiators nonce value
 	 * @param nonce_r		responders nonce value
@@ -53,7 +54,7 @@ struct keymat_v1_t {
 	 * @return				TRUE on success
 	 */
 	bool (*derive_ike_keys)(keymat_v1_t *this, proposal_t *proposal,
-							diffie_hellman_t *dh, chunk_t dh_other,
+							key_exchange_t *dh, chunk_t dh_other,
 							chunk_t nonce_i, chunk_t nonce_r, ike_sa_id_t *id,
 							auth_method_t auth, shared_key_t *shared_key);
 
@@ -72,7 +73,7 @@ struct keymat_v1_t {
 	 * @param integ_r		allocated responders integrity key
 	 */
 	bool (*derive_child_keys)(keymat_v1_t *this, proposal_t *proposal,
-						diffie_hellman_t *dh, uint32_t spi_i, uint32_t spi_r,
+						key_exchange_t *dh, uint32_t spi_i, uint32_t spi_r,
 						chunk_t nonce_i, chunk_t nonce_r,
 						chunk_t *encr_i, chunk_t *integ_i,
 						chunk_t *encr_r, chunk_t *integ_r);
