@@ -58,11 +58,6 @@ struct private_main_mode_t {
 	 */
 	phase1_t *ph1;
 
-	/**
-	 * IKE config to establish
-	 */
-	ike_cfg_t *ike_cfg;
-
 	/**
 	 * Peer config to use
 	 */
@@ -247,6 +242,7 @@ METHOD(task_t, build_i, status_t,
 	{
 		case MM_INIT:
 		{
+			ike_cfg_t *ike_cfg;
 			sa_payload_t *sa_payload;
 			linked_list_t *proposals;
 			packet_t *packet;
@@ -257,7 +253,7 @@ METHOD(task_t, build_i, status_t,
 				 this->ike_sa->get_other_host(this->ike_sa));
 			this->ike_sa->set_state(this->ike_sa, IKE_CONNECTING);
 
-			this->ike_cfg = this->ike_sa->get_ike_cfg(this->ike_sa);
+			ike_cfg = this->ike_sa->get_ike_cfg(this->ike_sa);
 			this->peer_cfg = this->ike_sa->get_peer_cfg(this->ike_sa);
 			this->peer_cfg->get_ref(this->peer_cfg);
 
@@ -275,7 +271,7 @@ METHOD(task_t, build_i, status_t,
 																 FALSE);
 			}
 			this->lifetime += this->peer_cfg->get_over_time(this->peer_cfg);
-			proposals = this->ike_cfg->get_proposals(this->ike_cfg);
+			proposals = ike_cfg->get_proposals(ike_cfg);
 			sa_payload = sa_payload_create_from_proposals_v1(proposals,
 									this->lifetime, 0, this->method, MODE_NONE,
 									ENCAP_NONE, 0);
@@ -364,11 +360,12 @@ METHOD(task_t, process_r, status_t,
 	{
 		case MM_INIT:
 		{
+			ike_cfg_t *ike_cfg;
 			linked_list_t *list;
 			sa_payload_t *sa_payload;
 			proposal_selection_flag_t flags = 0;
 
-			this->ike_cfg = this->ike_sa->get_ike_cfg(this->ike_sa);
+			ike_cfg = this->ike_sa->get_ike_cfg(this->ike_sa);
 			DBG0(DBG_IKE, "%H is initiating a Main Mode IKE_SA",
 				 message->get_source(message));
 			this->ike_sa->set_state(this->ike_sa, IKE_CONNECTING);
@@ -402,8 +399,7 @@ METHOD(task_t, process_r, status_t,
 			{
 				flags |= PROPOSAL_PREFER_SUPPLIED;
 			}
-			this->proposal = this->ike_cfg->select_proposal(this->ike_cfg,
-											list, flags);
+			this->proposal = ike_cfg->select_proposal(ike_cfg, list, flags);
 			list->destroy_offset(list, offsetof(proposal_t, destroy));
 			if (!this->proposal)
 			{
@@ -636,6 +632,7 @@ METHOD(task_t, process_i, status_t,
 		{
 			linked_list_t *list;
 			sa_payload_t *sa_payload;
+			ike_cfg_t *ike_cfg;
 			auth_method_t method;
 			proposal_selection_flag_t flags = 0;
 			uint32_t lifetime;
@@ -654,8 +651,8 @@ METHOD(task_t, process_i, status_t,
 			{
 				flags |= PROPOSAL_SKIP_PRIVATE;
 			}
-			this->proposal = this->ike_cfg->select_proposal(this->ike_cfg,
-															list, flags);
+			ike_cfg = this->ike_sa->get_ike_cfg(this->ike_sa);
+			this->proposal = ike_cfg->select_proposal(ike_cfg, list, flags);
 			list->destroy_offset(list, offsetof(proposal_t, destroy));
 			if (!this->proposal)
 			{
