@@ -102,7 +102,7 @@ METHOD(task_t, build_r, status_t,
 	private_ike_auth_lifetime_t *this, message_t *message)
 {
 	if (message->get_exchange_type(message) == IKE_AUTH &&
-		this->ike_sa->get_state(this->ike_sa) == IKE_ESTABLISHED)
+		this->ike_sa->has_condition(this->ike_sa, COND_AUTHENTICATED))
 	{
 		if (!ike_sa_can_reauthenticate(this->ike_sa))
 		{
@@ -117,7 +117,7 @@ METHOD(task_t, process_i, status_t,
 	private_ike_auth_lifetime_t *this, message_t *message)
 {
 	if (message->get_exchange_type(message) == IKE_AUTH &&
-		this->ike_sa->get_state(this->ike_sa) == IKE_ESTABLISHED)
+		this->ike_sa->has_condition(this->ike_sa, COND_AUTHENTICATED))
 	{
 		process_payloads(this, message);
 		return SUCCESS;
