@@ -474,7 +474,7 @@ METHOD(task_t, build_r, status_t,
 	   private_ike_mobike_t *this, message_t *message)
 {
 	if (message->get_exchange_type(message) == IKE_AUTH &&
-		this->ike_sa->get_state(this->ike_sa) == IKE_ESTABLISHED)
+		this->ike_sa->has_condition(this->ike_sa, COND_AUTHENTICATED))
 	{	/* in last IKE_AUTH only */
 		if (this->ike_sa->supports_extension(this->ike_sa, EXT_MOBIKE))
 		{
@@ -503,7 +503,7 @@ METHOD(task_t, process_i, status_t,
 	   private_ike_mobike_t *this, message_t *message)
 {
 	if (message->get_exchange_type(message) == IKE_AUTH &&
-		this->ike_sa->get_state(this->ike_sa) == IKE_ESTABLISHED)
+		this->ike_sa->has_condition(this->ike_sa, COND_AUTHENTICATED))
 	{	/* in last IKE_AUTH only */
 		process_payloads(this, message);
 		return SUCCESS;
