@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2012-2014 Andreas Steffen
- * HSR Hochschule fuer Technik Rapperswil
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -81,7 +82,7 @@ METHOD(pa_tnc_attr_t, build, void,
 }
 
 METHOD(pa_tnc_attr_t, process, status_t,
-	private_ita_attr_angel_t *this, u_int32_t *offset)
+	private_ita_attr_angel_t *this, uint32_t *offset)
 {
 	return SUCCESS;
 }
