@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2011-2014 Andreas Steffen
- * HSR Hochschule fuer Technik Rapperswil
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -141,10 +142,14 @@ METHOD(imc_state_t, get_contracts, seg_contract_manager_t*,
 	return this->contracts;
 }
 
-METHOD(imc_state_t, change_state, void,
+METHOD(imc_state_t, change_state, TNC_ConnectionState,
 	private_imc_test_state_t *this, TNC_ConnectionState new_state)
 {
+	TNC_ConnectionState old_state;
+
+	old_state = this->state;
 	this->state = new_state;
+	return old_state;
 }
 
 METHOD(imc_state_t, set_result, void,
@@ -202,6 +207,12 @@ METHOD(imc_state_t, get_result, bool,
 	return eval != TNC_IMV_EVALUATION_RESULT_DONT_KNOW;
 }
 
+METHOD(imc_state_t, reset, void,
+	private_imc_test_state_t *this)
+{
+	/* nothing to reset */
+}
+
 METHOD(imc_state_t, destroy, void,
 	private_imc_test_state_t *this)
 {
@@ -277,6 +288,7 @@ imc_state_t *imc_test_state_create(TNC_ConnectionID connection_id,
 				.change_state = _change_state,
 				.set_result = _set_result,
 				.get_result = _get_result,
+				.reset = _reset,
 				.destroy = _destroy,
 			},
 			.get_command = _get_command,
