@@ -1,4 +1,5 @@
 /*
+ * Copyright (C) 2013 Tobias Brunner
  * Copyright (C) 2012 Giuliano Grassi
  * Copyright (C) 2012 Ralf Sager
  *
@@ -47,6 +48,13 @@ struct ipsec_event_relay_t {
 	void (*expire)(ipsec_event_relay_t *this, uint8_t protocol, uint32_t spi,
 				   host_t *dst, bool hard);
 
+	/**
+	 * Raise an acquire event.
+	 *
+	 * @param reqid			reqid of the policy for which to acquire an SA
+	 */
+	void (*acquire)(ipsec_event_relay_t *this, uint32_t reqid);
+
 	/**
 	 * Register a listener to events raised by this manager
 	 *
