@@ -1,9 +1,8 @@
 /*
  * Copyright (C) 2012 Tobias Brunner
- * HSR Hochschule fuer Technik Rapperswil
- *
  * Copyright (C) 2010 Martin Willi
- * Copyright (C) 2010 revosec AG
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -122,13 +121,16 @@ static bool read_uint16_internal(private_bio_reader_t *this, uint16_t *res,
 static bool read_uint24_internal(private_bio_reader_t *this, uint32_t *res,
 								 bool from_end)
 {
+	uint32_t tmp;
+
 	if (this->buf.len < 3)
 	{
 		DBG1(DBG_LIB, "%d bytes insufficient to parse u_int24 data",
 			 this->buf.len);
 		return FALSE;
 	}
-	*res = untoh32(get_ptr_end(this, 3, from_end)) >> 8;
+	memcpy(&tmp, get_ptr_end(this, 3, from_end), 3);
+	*res = ntohl(tmp) >> 8;
 	this->buf = chunk_skip_end(this->buf, 3, from_end);
 	return TRUE;
 }
