@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2010-2019 Tobias Brunner
+ * Copyright (C) 2016-2024 Andreas Steffen
+ * Copyright (C) 2010-2024 Tobias Brunner
  * Copyright (C) 2005-2010 Martin Willi
  * Copyright (C) 2005 Jan Hutter
  *
@@ -18,6 +19,9 @@
 
 #include "key_exchange.h"
 
+#include <collections/hashtable.h>
+#include <threading/mutex.h>
+
 ENUM_BEGIN(key_exchange_method_names, KE_NONE, MODP_1024_BIT,
 	"KE_NONE",
 	"MODP_768",
@@ -33,7 +37,7 @@ ENUM_NEXT(key_exchange_method_names, MODP_2048_BIT, ECP_521_BIT, MODP_1536_BIT,
 	"ECP_256",
 	"ECP_384",
 	"ECP_521");
-ENUM_NEXT(key_exchange_method_names, MODP_1024_160, CURVE_448, ECP_521_BIT,
+ENUM_NEXT(key_exchange_method_names, MODP_1024_160, ML_KEM_1024, ECP_521_BIT,
 	"MODP_1024_160",
 	"MODP_2048_224",
 	"MODP_2048_256",
@@ -44,17 +48,15 @@ ENUM_NEXT(key_exchange_method_names, MODP_1024_160, CURVE_448, ECP_521_BIT,
 	"ECP_384_BP",
 	"ECP_512_BP",
 	"CURVE_25519",
-	"CURVE_448");
-ENUM_NEXT(key_exchange_method_names, MODP_NULL, MODP_NULL, CURVE_448,
+	"CURVE_448",
+	"GOST3410_256",
+	"GOST3410_512",
+	"ML_KEM_512",
+	"ML_KEM_768",
+	"ML_KEM_1024");
+ENUM_NEXT(key_exchange_method_names, MODP_NULL, MODP_NULL, ML_KEM_1024,
 	"MODP_NULL");
-ENUM_NEXT(key_exchange_method_names, NTRU_112_BIT, NTRU_256_BIT, MODP_NULL,
-	"NTRU_112",
-	"NTRU_128",
-	"NTRU_192",
-	"NTRU_256");
-ENUM_NEXT(key_exchange_method_names, NH_128_BIT, NH_128_BIT, NTRU_256_BIT,
-	"NEWHOPE_128");
-ENUM_NEXT(key_exchange_method_names, MODP_CUSTOM, MODP_CUSTOM, NH_128_BIT,
+ENUM_NEXT(key_exchange_method_names, MODP_CUSTOM, MODP_CUSTOM, MODP_NULL,
 	"MODP_CUSTOM");
 ENUM_END(key_exchange_method_names, MODP_CUSTOM);
 
@@ -73,7 +75,7 @@ ENUM_NEXT(key_exchange_method_names_short, MODP_2048_BIT, ECP_521_BIT, MODP_1536
 	"ecp256",
 	"ecp384",
 	"ecp521");
-ENUM_NEXT(key_exchange_method_names_short, MODP_1024_160, CURVE_448, ECP_521_BIT,
+ENUM_NEXT(key_exchange_method_names_short, MODP_1024_160, ML_KEM_1024, ECP_521_BIT,
 	"modp1024s160",
 	"modp2048s224",
 	"modp2048s256",
@@ -84,17 +86,15 @@ ENUM_NEXT(key_exchange_method_names_short, MODP_1024_160, CURVE_448, ECP_521_BIT
 	"ecp384bp",
 	"ecp512bp",
 	"curve25519",
-	"curve448");
-ENUM_NEXT(key_exchange_method_names_short, MODP_NULL, MODP_NULL, CURVE_448,
+	"curve448",
+	"gost256",
+	"gost512",
+	"mlkem512",
+	"mlkem768",
+	"mlkem1024");
+ENUM_NEXT(key_exchange_method_names_short, MODP_NULL, MODP_NULL, ML_KEM_1024,
 	"modpnull");
-ENUM_NEXT(key_exchange_method_names_short, NTRU_112_BIT, NTRU_256_BIT, MODP_NULL,
-	"ntru112",
-	"ntru128",
-	"ntru192",
-	"ntru256");
-ENUM_NEXT(key_exchange_method_names_short, NH_128_BIT, NH_128_BIT, NTRU_256_BIT,
-	"newhope128");
-ENUM_NEXT(key_exchange_method_names_short, MODP_CUSTOM, MODP_CUSTOM, NH_128_BIT,
+ENUM_NEXT(key_exchange_method_names_short, MODP_CUSTOM, MODP_CUSTOM, MODP_NULL,
 	"modpcustom");
 ENUM_END(key_exchange_method_names_short, MODP_CUSTOM);
 
@@ -475,10 +475,68 @@ static struct {
 	},
 };
 
+/**
+ * Proposal tokens for additional key exchanges.
+ */
+static hashtable_t *tokens;
+
+/**
+ * Mutex to safely access cached tokens.
+ */
+static mutex_t *mutex;
+
+/**
+ * Destroy an allocated proposal token.
+ */
+static void token_destroy(proposal_token_t *this)
+{
+	free(this->name);
+	free(this);
+}
+
+/**
+ * Parse ke<1-7>_<method> for additional key exchange methods.
+ */
+static proposal_token_t *additional_key_exchange_parser(const char *algname)
+{
+	proposal_token_t *token;
+	const proposal_token_t *base;
+	u_int num;
+	char prefix[3], alg[256];
+
+	if (!algname || sscanf(algname, "%2s%1u_%255s", prefix, &num, alg) != 3 ||
+		!strcaseeq(prefix, "ke"))
+	{
+		return NULL;
+	}
+	mutex->lock(mutex);
+	token = tokens->get(tokens, algname);
+	if (token || num < 1 || num > 7)
+	{
+		goto done;
+	}
+	base = lib->proposal->get_token(lib->proposal, alg);
+	if (!base || base->type != KEY_EXCHANGE_METHOD)
+	{
+		goto done;
+	}
+	INIT(token,
+		.name = strdup(algname),
+		.type = ADDITIONAL_KEY_EXCHANGE_1 + num - 1,
+		.algorithm = base->algorithm,
+		.keysize = base->keysize,
+	);
+	tokens->put(tokens, token->name, token);
+
+done:
+	mutex->unlock(mutex);
+	return token;
+}
+
 /*
  * Described in header
  */
-void diffie_hellman_init()
+void key_exchange_init()
 {
 	int i;
 
@@ -498,6 +556,20 @@ void diffie_hellman_init()
 			dh_params[i].public.exp_len = dh_params[i].public.prime.len;
 		}
 	}
+
+	mutex = mutex_create(MUTEX_TYPE_RECURSIVE);
+	tokens = hashtable_create(hashtable_hash_str, hashtable_equals_str, 4);
+	lib->proposal->register_algname_parser(lib->proposal,
+										   additional_key_exchange_parser);
+}
+
+/*
+ * Described in header
+ */
+void key_exchange_deinit()
+{
+	tokens->destroy_function(tokens, (void*)token_destroy);
+	mutex->destroy(mutex);
 }
 
 /*
@@ -535,6 +607,24 @@ bool key_exchange_is_ecdh(key_exchange_method_t ke)
 		case ECP_512_BP:
 		case CURVE_25519:
 		case CURVE_448:
+		case GOST3410_256:
+		case GOST3410_512:
+			return TRUE;
+		default:
+			return FALSE;
+	}
+}
+
+/*
+ * Described in header
+ */
+bool key_exchange_is_kem(key_exchange_method_t ke)
+{
+	switch (ke)
+	{
+		case ML_KEM_512:
+		case ML_KEM_768:
+		case ML_KEM_1024:
 			return TRUE;
 		default:
 			return FALSE;
@@ -595,11 +685,15 @@ bool key_exchange_verify_pubkey(key_exchange_method_t ke, chunk_t value)
 		case CURVE_448:
 			valid = value.len == 56;
 			break;
-		case NTRU_112_BIT:
-		case NTRU_128_BIT:
-		case NTRU_192_BIT:
-		case NTRU_256_BIT:
-		case NH_128_BIT:
+		case GOST3410_256:
+			valid = value.len == 64;
+			break;
+		case GOST3410_512:
+			valid = value.len == 128;
+			break;
+		case ML_KEM_512:
+		case ML_KEM_768:
+		case ML_KEM_1024:
 			/* verification currently not supported, do in plugin */
 			valid = FALSE;
 			break;
@@ -619,3 +713,43 @@ bool key_exchange_verify_pubkey(key_exchange_method_t ke, chunk_t value)
 	}
 	return valid;
 }
+
+/*
+ * Described in header
+ */
+bool key_exchange_concat_secrets(array_t *kes, chunk_t *first,
+								 chunk_t *others)
+{
+	key_exchange_t *ke;
+	chunk_t secret;
+	int i;
+
+	if (!array_count(kes))
+	{
+		return FALSE;
+	}
+	*first = chunk_empty;
+	*others = chunk_empty;
+	for (i = 0; i < array_count(kes); i++)
+	{
+		if (array_get(kes, i, &ke) &&
+			ke->get_shared_secret(ke, &secret))
+		{
+			if (i == 0)
+			{
+				*first = secret;
+			}
+			else
+			{
+				*others = chunk_cat("ss", *others, secret);
+			}
+		}
+		else
+		{
+			chunk_clear(first);
+			chunk_clear(others);
+			return FALSE;
+		}
+	}
+	return TRUE;
+}
