@@ -52,6 +52,12 @@ enum transform_type_t {
 	KEY_DERIVATION_FUNCTION = 262,
 };
 
+/**
+ * Maximum number of additional key exchanges.
+ */
+#define MAX_ADDITIONAL_KEY_EXCHANGES (ADDITIONAL_KEY_EXCHANGE_7 - \
+									  ADDITIONAL_KEY_EXCHANGE_1 + 1)
+
 /**
  * enum names for transform_type_t.
  */
