@@ -142,7 +142,7 @@ eap_vendor_type_t *eap_vendor_type_from_string(char *str)
 	enumerator_t *enumerator;
 	eap_vendor_type_t *result = NULL;
 	eap_type_t type = 0;
-	uint32_t vendor = 0;
+	pen_t vendor = 0;
 	char *part, *end;
 
 	/* parse EAP method string of the form: [eap-]type[-vendor] */
@@ -170,7 +170,7 @@ eap_vendor_type_t *eap_vendor_type_from_string(char *str)
 		}
 		errno = 0;
 		vendor = strtoul(part, &end, 0);
-		if (*end != '\0' || errno)
+		if (*end != '\0' || errno || vendor >= PEN_UNASSIGNED)
 		{
 			DBG1(DBG_LIB, "invalid EAP vendor: %s", part);
 			type = 0;
