@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2013 Martin Willi
- * Copyright (C) 2013 revosec AG
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -25,9 +26,6 @@ typedef struct stream_t stream_t;
 
 #include <library.h>
 
-#include <sys/un.h>
-#include <sys/socket.h>
-
 /**
  * Constructor function prototype for stream_t.
  *
@@ -53,7 +51,7 @@ typedef stream_t*(*stream_constructor_t)(char *uri);
 typedef bool (*stream_cb_t)(void *data, stream_t *stream);
 
 /**
- * Abstraction of a Berkley socket using stream semantics.
+ * Abstraction of a Berkeley socket using stream semantics.
  */
 struct stream_t {
 
@@ -137,54 +135,6 @@ struct stream_t {
 	void (*destroy)(stream_t *this);
 };
 
-/**
- * Create a stream for UNIX sockets.
- *
- * UNIX URIs start with unix://, followed by the socket path. For absolute
- * paths, an URI looks something like:
- *
- *   unix:///path/to/socket
- *
- * @param uri		UNIX socket specific URI, must start with "unix://"
- * @return			stream instance, NULL on failure
- */
-stream_t *stream_create_unix(char *uri);
-
-/**
- * Helper function to parse a unix:// URI to a sockaddr
- *
- * @param uri		URI
- * @param addr		sockaddr
- * @return			length of sockaddr, -1 on error
- */
-int stream_parse_uri_unix(char *uri, struct sockaddr_un *addr);
-
-/**
- * Create a stream for TCP sockets.
- *
- * TCP URIs start with tcp://, followed by a hostname (FQDN or IP), followed
- * by a colon separated port. A full TCP uri looks something like:
- *
- *   tcp://srv.example.com:5555
- *   tcp://0.0.0.0:1234
- *   tcp://[fec2::1]:7654
- *
- * There is no default port, so a colon after tcp:// is mandatory.
- *
- * @param uri		TCP socket specific URI, must start with "tcp://"
- * @return			stream instance, NULL on failure
- */
-stream_t *stream_create_tcp(char *uri);
-
-/**
- * Helper function to parse a tcp:// URI to a sockaddr
- *
- * @param uri		URI
- * @param addr		sockaddr, large enough for URI
- * @return			length of sockaddr, -1 on error
- */
-int stream_parse_uri_tcp(char *uri, struct sockaddr *addr);
-
 /**
  * Create a stream from a file descriptor.
  *
