@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2006 Martin Willi
- * Hochschule fuer Technik Rapperswil
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -114,9 +115,9 @@ METHOD(prf_t, get_bytes, bool,
 	uint8_t *xkey = this->key;
 	uint8_t one[this->b];
 
-	if (!w)
+	if (!w || !this->b)
 	{
-		/* append mode is not supported */
+		/* append mode is not supported, the other check is to make GCC happy */
 		return FALSE;
 	}
 
