@@ -204,8 +204,8 @@ static BIGNUM *calculate_public_key(BIGNUM *priv, const BIGNUM *g,
 	return pub;
 }
 
-METHOD(key_exchange_t, set_private_key, bool,
-	private_openssl_diffie_hellman_t *this, chunk_t value)
+METHOD(key_exchange_t, set_seed, bool,
+	private_openssl_diffie_hellman_t *this, chunk_t value, drbg_t *drbg)
 {
 	BIGNUM *priv, *g = NULL, *p = NULL, *pub = NULL;
 	OSSL_PARAM_BLD *bld = NULL;
@@ -254,8 +254,8 @@ error:
 
 #else /* OPENSSL_VERSION_NUMBER */
 
-METHOD(key_exchange_t, set_private_key, bool,
-	private_openssl_diffie_hellman_t *this, chunk_t value)
+METHOD(key_exchange_t, set_seed, bool,
+	private_openssl_diffie_hellman_t *this, chunk_t value, drbg_t *drbg)
 {
 	BIGNUM *privkey;
 
@@ -304,7 +304,7 @@ openssl_diffie_hellman_t *openssl_diffie_hellman_create(
 				.get_shared_secret = _get_shared_secret,
 				.set_public_key = _set_public_key,
 				.get_public_key = _get_public_key,
-				.set_private_key = _set_private_key,
+				.set_seed = _set_seed,
 				.get_method = _get_method,
 				.destroy = _destroy,
 			},
