@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2013 Martin Willi
- * Copyright (C) 2013 revosec AG
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -204,7 +205,7 @@ Suite *printf_suite_create()
 	tcase_add_test(tc, test_printf_err);
 	suite_add_tcase(s, tc);
 
-	tc = tcase_create("unsiged");
+	tc = tcase_create("unsigned");
 	tcase_add_test(tc, test_printf_unsigned);
 	suite_add_tcase(s, tc);
 
