@@ -1,7 +1,8 @@
 /*
- * Copyright (C) 2008-2014 Tobias Brunner
+ * Copyright (C) 2008-2018 Tobias Brunner
  * Copyright (C) 2005-2008 Martin Willi
- * Hochschule fuer Technik Rapperswil
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -31,18 +32,26 @@ ENUM(status_names, SUCCESS, NEED_MORE,
 	"NEED_MORE",
 );
 
-/**
- * returns FAILED
+/*
+ * Described in header
  */
 status_t return_failed()
 {
 	return FAILED;
 }
 
-/**
- * returns SUCCESS
+/*
+ * Described in header
  */
 status_t return_success()
 {
 	return SUCCESS;
 }
+
+/*
+ * Described in header
+ */
+status_t return_need_more()
+{
+	return NEED_MORE;
+}
