@@ -1,7 +1,8 @@
 /*
  * Copyright (C) 2018 Tobias Brunner
- * Copyright (C) 2016-2019 Andreas Steffen
- * HSR Hochschule fuer Technik Rapperswil
+ * Copyright (C) 2016-2020 Andreas Steffen
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -22,10 +23,13 @@
 #include <asn1/asn1.h>
 #include <asn1/oid.h>
 #include <bio/bio_reader.h>
+#include <bio/bio_writer.h>
 #include <threading/mutex.h>
 
 #include <tpm20.h>
 
+#include <unistd.h>
+
 #ifdef TSS2_TCTI_TABRMD
 #include <tcti/tcti-tabrmd.h>
 #endif /* TSS2_TCTI_TABRMD */
@@ -39,6 +43,9 @@
 
 #define LABEL	"TPM 2.0 -"
 
+#define PLATFORM_PCR	24
+#define MAX_PCR_BANKS	 4
+
 typedef struct private_tpm_tss_tss2_t private_tpm_tss_tss2_t;
 
 /**
@@ -61,6 +68,11 @@ struct private_tpm_tss_tss2_t {
 	 */
 	TSS2_SYS_CONTEXT  *sys_context;
 
+	/**
+	 * TPM version info
+	 */
+	chunk_t version_info;
+
 	/**
 	 * Number of supported algorithms
 	 */
@@ -71,6 +83,16 @@ struct private_tpm_tss_tss2_t {
 	 */
 	TPM_ALG_ID supported_algs[TPM_PT_ALGORITHM_SET];
 
+		/**
+	 * Number of assigned PCR banks
+	 */
+	size_t assigned_pcrs_count;
+
+	/**
+	 * List of assigned PCR banks
+	 */
+	TPM_ALG_ID assigned_pcrs[MAX_PCR_BANKS];
+
 	/**
 	 * Is TPM FIPS 186-4 compliant ?
 	 */
@@ -158,16 +180,36 @@ static bool is_supported_alg(private_tpm_tss_tss2_t *this, TPM_ALG_ID alg_id)
 }
 
 /**
- * Get a list of supported algorithms
+ * Get the TPM version_info and a list of supported algorithms
+ *
+ *					   1				   2				   3
+ *   0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+ *
+ *  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ *  |  TPM 2.0 Version_Info Tag     |   Reserved    |   Locality    |
+ *  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ *  |                            Revision                           |
+ *  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ *  |                              Year                             |
+ *  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ *  |                             Vendor                            |
+ *  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
  */
+#define TPM2_VERSION_INFO_TAG       0x0200
+#define TPM2_VERSION_INFO_RESERVED  0x00
+#define TPM2_VERSION_INFO_SIZE      16
+#define TPM2_DEFAULT_LOCALITY       3
+
 static bool get_algs_capability(private_tpm_tss_tss2_t *this)
 {
 	TPMS_CAPABILITY_DATA cap_data;
 	TPMS_TAGGED_PROPERTY tp;
 	TPMI_YES_NO more_data;
 	TPM_ALG_ID alg;
+	bio_writer_t *writer;
 	bool fips_140_2 = FALSE;
-	uint32_t rval, i, offset, revision = 0, year = 0;
+	uint32_t rval, i, offset, revision = 0, year = 0, vendor = 0;
+	uint8_t locality = TPM2_DEFAULT_LOCALITY;
 	size_t len = BUF_LEN;
 	char buf[BUF_LEN], manufacturer[5], vendor_string[17];
 	char *pos = buf;
@@ -200,6 +242,7 @@ static bool get_algs_capability(private_tpm_tss_tss2_t *this)
 				year = tp.value;
 				break;
 			case TPM_PT_MANUFACTURER:
+				vendor = tp.value;
 				htoun32(manufacturer, tp.value);
 				break;
 			case TPM_PT_VENDOR_STRING_1:
@@ -229,6 +272,23 @@ static bool get_algs_capability(private_tpm_tss_tss2_t *this)
 		 manufacturer, vendor_string, (float)revision/100, year,
 		 fips_140_2 ? "FIPS 140-2" : (this->fips_186_4 ? "FIPS 186-4" : ""));
 
+	/* determine if TPM uses old event digest format and a different locality */
+	if (streq(manufacturer, "INTC") && revision == 116 && year == 2016)
+	{
+		locality = 0;
+	}
+
+	/* construct TPM 2.0 version_info object */
+	writer = bio_writer_create(  TPM2_VERSION_INFO_SIZE);
+	writer->write_uint16(writer, TPM2_VERSION_INFO_TAG);
+	writer->write_uint8(writer,  TPM2_VERSION_INFO_RESERVED);
+	writer->write_uint8(writer,  locality);
+	writer->write_uint32(writer, revision);
+	writer->write_uint32(writer, year);
+	writer->write_uint32(writer, vendor);
+	this->version_info = writer->extract_buf(writer);
+	writer->destroy(writer);
+
 	/* get supported algorithms */
 	this->mutex->lock(this->mutex);
 	rval = Tss2_Sys_GetCapability(this->sys_context, 0, TPM_CAP_ALGS,
@@ -267,7 +327,7 @@ static bool get_algs_capability(private_tpm_tss_tss2_t *this)
 	this->mutex->unlock(this->mutex);
 	if (rval != TPM_RC_SUCCESS)
 	{
-		DBG1(DBG_PTS, "%s GetCapability failed for TPM_ECC_CURVES: 0x%06x",
+		DBG1(DBG_PTS, "%s GetCapability failed for TPM_CAP_ECC_CURVES: 0x%06x",
 					   LABEL, rval);
 		return FALSE;
 	}
@@ -290,6 +350,40 @@ static bool get_algs_capability(private_tpm_tss_tss2_t *this)
 	}
 	DBG2(DBG_PTS, "%s ECC curves:%s", LABEL, buf);
 
+	/* get assigned PCR banks */
+	this->mutex->lock(this->mutex);
+	rval = Tss2_Sys_GetCapability(this->sys_context, 0, TPM_CAP_PCRS,
+						0, MAX_PCR_BANKS, &more_data, &cap_data, 0);
+	this->mutex->unlock(this->mutex);
+	if (rval != TPM_RC_SUCCESS)
+	{
+		DBG1(DBG_PTS, "%s GetCapability failed for TPM_CAP_PCRS: 0x%06x",
+					   LABEL, rval);
+		return FALSE;
+	}
+
+	/* Number of assigned PCR banks */
+	this->assigned_pcrs_count = cap_data.data.assignedPCR.count;
+
+	/* reset print buffer */
+	pos = buf;
+	len = BUF_LEN;
+
+	/* store and print assigned PCR banks */
+	for (i = 0; i < cap_data.data.assignedPCR.count; i++)
+	{
+		alg = cap_data.data.assignedPCR.pcrSelections[i].hash;
+		this->assigned_pcrs[i] = alg;
+		written = snprintf(pos, len, " %N", tpm_alg_id_names, alg);
+		if (written < 0 || written >= len)
+		{
+			break;
+		}
+		pos += written;
+		len -= written;
+	}
+	DBG2(DBG_PTS, "%s PCR banks:%s", LABEL, buf);
+
 	return TRUE;
 }
 
@@ -429,7 +523,7 @@ METHOD(tpm_tss_t, get_version, tpm_version_t,
 METHOD(tpm_tss_t, get_version_info, chunk_t,
 	private_tpm_tss_tss2_t *this)
 {
-	return chunk_empty;
+	return this->version_info;
 }
 
 /**
@@ -477,16 +571,13 @@ METHOD(tpm_tss_t, get_public, chunk_t,
 {
 	TPM2B_PUBLIC public = { { 0, } };
 	TPM_ALG_ID sig_alg, digest_alg;
-	chunk_t aik_blob, aik_pubkey = chunk_empty;
+	chunk_t aik_pubkey = chunk_empty;
 
 	if (!read_public(this, handle, &public))
 	{
 		return chunk_empty;
 	}
 
-	aik_blob = chunk_create((u_char*)&public, sizeof(public));
-	DBG3(DBG_LIB, "%s public key blob: %B", LABEL, &aik_blob);
-
 	/* convert TSS 2.0 public key blot into PKCS#1 format */
 	switch (public.t.publicArea.type)
 	{
@@ -651,27 +742,44 @@ METHOD(tpm_tss_t, supported_signature_schemes, enumerator_t*,
 									(void*)signature_params_destroy);
 }
 
+METHOD(tpm_tss_t, has_pcr_bank, bool,
+	private_tpm_tss_tss2_t *this, hash_algorithm_t alg)
+{
+	TPM_ALG_ID alg_id;
+	int i;
+
+	alg_id = hash_alg_to_tpm_alg_id(alg);
+
+	for (i = 0; i < this->assigned_pcrs_count; i++)
+	{
+		if (this->assigned_pcrs[i] == alg_id)
+		{
+			return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
 /**
  * Configure a PCR Selection assuming a maximum of 24 registers
  */
 static bool init_pcr_selection(private_tpm_tss_tss2_t *this, uint32_t pcrs,
 							   hash_algorithm_t alg, TPML_PCR_SELECTION *pcr_sel)
 {
-	TPM_ALG_ID alg_id;
 	uint32_t pcr;
 
-	/* check if hash algorithm is supported by TPM */
-	alg_id = hash_alg_to_tpm_alg_id(alg);
-	if (!is_supported_alg(this, alg_id))
+	/* check if there is an assigned PCR bank for this hash algorithm */
+	if (!has_pcr_bank(this, alg))
 	{
-		DBG1(DBG_PTS, "%s %N hash algorithm not supported by TPM",
+		DBG1(DBG_PTS, "%s %N hash algorithm not supported by any PCR bank",
 			 LABEL, hash_algorithm_short_names, alg);
 		return FALSE;
 	}
 
 	/* initialize the PCR Selection structure,*/
 	pcr_sel->count = 1;
-	pcr_sel->pcrSelections[0].hash = alg_id;
+	pcr_sel->pcrSelections[0].hash = hash_alg_to_tpm_alg_id(alg);
 	pcr_sel->pcrSelections[0].sizeofSelect = 3;
 	pcr_sel->pcrSelections[0].pcrSelect[0] = 0;
 	pcr_sel->pcrSelections[0].pcrSelect[1] = 0;
@@ -738,7 +846,6 @@ METHOD(tpm_tss_t, extend_pcr, bool,
 	chunk_t data, hash_algorithm_t alg)
 {
 	uint32_t rval;
-	TPM_ALG_ID alg_id;
 	TPML_DIGEST_VALUES digest_values;
 	TPMS_AUTH_COMMAND  session_data_cmd;
 	TPMS_AUTH_RESPONSE session_data_rsp;
@@ -762,17 +869,16 @@ METHOD(tpm_tss_t, extend_pcr, bool,
 
 	*( (uint8_t *)((void *)&session_data_cmd.sessionAttributes ) ) = 0;
 
-	/* check if hash algorithm is supported by TPM */
-	alg_id = hash_alg_to_tpm_alg_id(alg);
-	if (!is_supported_alg(this, alg_id))
+	/* check if there is an assigned PCR bank for this hash algorithm */
+	if (!has_pcr_bank(this, alg))
 	{
-		DBG1(DBG_PTS, "%s %N hash algorithm not supported by TPM",
+		DBG1(DBG_PTS, "%s %N hash algorithm not supported by any PCR bank",
 			 LABEL, hash_algorithm_short_names, alg);
 		return FALSE;
 	}
 
 	digest_values.count = 1;
-	digest_values.digests[0].hashAlg = alg_id;
+	digest_values.digests[0].hashAlg = hash_alg_to_tpm_alg_id(alg);
 
 	switch (alg)
 	{
@@ -1302,11 +1408,72 @@ METHOD(tpm_tss_t, get_data, bool,
 	return TRUE;
 }
 
+METHOD(tpm_tss_t, get_event_digest, bool,
+	private_tpm_tss_tss2_t *this, int fd, hash_algorithm_t alg, chunk_t *digest)
+{
+	uint8_t digest_buf[HASH_SIZE_SHA512];
+	uint32_t digest_count;
+	size_t digest_len = 0;
+	hash_algorithm_t hash_alg;
+	TPM_ALG_ID alg_id;
+
+	if (read(fd, &digest_count, 4) != 4)
+	{
+		return FALSE;
+	}
+	while (digest_count--)
+	{
+		if (read(fd, &alg_id, 2) != 2)
+		{
+			return FALSE;
+		}
+		hash_alg = hash_alg_from_tpm_alg_id(alg_id);
+
+		switch (hash_alg)
+		{
+			case HASH_SHA1:
+				digest_len = HASH_SIZE_SHA1;
+				break;
+			case HASH_SHA256:
+				digest_len = HASH_SIZE_SHA256;
+				break;
+			case HASH_SHA384:
+				digest_len = HASH_SIZE_SHA384;
+				break;
+			case HASH_SHA512:
+				digest_len = HASH_SIZE_SHA512;
+				break;
+			default:
+				DBG2(DBG_PTS, "alg_id: 0x%04x", alg_id);
+				return FALSE;
+		}
+		if (hash_alg == alg)
+		{
+			*digest = chunk_alloc(digest_len);
+			if (read(fd, digest->ptr, digest_len) != digest_len)
+			{
+				return FALSE;
+			}
+		}
+		else
+		{
+			/* read without storing */
+			if (read(fd, digest_buf, digest_len) != digest_len)
+			{
+				return FALSE;
+			}
+		}
+	}
+
+	return TRUE;
+}
+
 METHOD(tpm_tss_t, destroy, void,
 	private_tpm_tss_tss2_t *this)
 {
 	finalize_context(this);
 	this->mutex->destroy(this->mutex);
+	free(this->version_info.ptr);
 	free(this);
 }
 
@@ -1325,12 +1492,14 @@ tpm_tss_t *tpm_tss_tss2_create()
 			.generate_aik = _generate_aik,
 			.get_public = _get_public,
 			.supported_signature_schemes = _supported_signature_schemes,
+			.has_pcr_bank = _has_pcr_bank,
 			.read_pcr = _read_pcr,
 			.extend_pcr = _extend_pcr,
 			.quote = _quote,
 			.sign = _sign,
 			.get_random = _get_random,
 			.get_data = _get_data,
+			.get_event_digest = _get_event_digest,
 			.destroy = _destroy,
 		},
 		.mutex = mutex_create(MUTEX_TYPE_DEFAULT),
