@@ -6,7 +6,7 @@
   <table class="peer">
     <tr>
       <td><label for="alias">Alias</label></td>
-      <td><input type="text" id="alias" name="alias" maxlength="30" class="focus" value="<?cs var:alias ?>"/></td>
+      <td><input type="text" id="alias" name="alias" maxlength="30" autofocus value="<?cs var:alias ?>"/></td>
     </tr>
     <tr>
       <td valign="top"><label for="public_key">Public Key</label></td>
@@ -16,7 +16,7 @@
       <td></td>
       <td align="right">
         <input type="submit" value="Back" name="back"/>
-        <input type="submit" value="Delete" name="delete" onclick="return confirm('Permanently delete this peer?')"/> 
+        <input type="submit" value="Delete" name="delete" onclick="return confirm('Permanently delete this peer?')"/>
       	<input type="submit" value="Save" name="save"/>
       </td>
     </tr>
