@@ -183,21 +183,17 @@ running_any()
 
 function searchandreplace {
 
-    SEARCHSTRING="$1"
-    REPLACESTRING="$2"
-    DESTDIR="$3"
+	SEARCHSTRING="$1"
+	REPLACESTRING="$2"
+	DESTDIR="$3"
 
-    [ -d "$DESTDIR" ] || die "$DESTDIR is not a directory!"
+	[ -d "$DESTDIR" ] || die "$DESTDIR is not a directory!"
 
 
-    ###########################################
-    # search and replace in each found file the
-    # given string
-    #
-
-    for eachfoundfile in `find $DESTDIR -type f`
-    do
-        sed -i -e "s/$SEARCHSTRING/$REPLACESTRING/g" "$eachfoundfile"
-    done
-
+	###########################################
+	# search and replace in each found file the
+	# given string
+	#
+	grep -rlZ --exclude='*.pem' "$SEARCHSTRING" $DESTDIR | \
+		xargs -0 -I@ sed -i -e "s/$SEARCHSTRING/$REPLACESTRING/g" @
 }
